<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Admin\Point;
use Exception;

class PointsController extends Controller
{

    public $pointModel;

    public function __construct(Point $point)
    {
        $this->pointModel = $point;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if (auth()->user()->cant('index', $this->pointModel)) {
            abort(403, '포인트 관리 목록 보기에 대한 권한이 없습니다.');
        }

        $params = $this->pointModel->getPointIndexParams($request);

        return view('admin.points.index', $params);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if (auth()->user()->cant('create', $this->pointModel)) {
            abort(403, '포인트 추가에 대한 권한이 없습니다.');
        }

        $rule = [
            'email' => 'required|email',
            'point' => 'required|numeric',
            'content' => 'required',
        ];

        $this->validate($request, $rule);
		
        $this->pointModel->givePoint($request);

        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if (auth()->user()->cant('delete', $this->pointModel)) {
            abort(403, '포인트 삭제에 대한 권한이 없습니다.');
        }

        $this->pointModel->deletePointOnAdmin($id);

        return redirect()->back();
    }
}
